@@ -139,4 +139,30 @@
 # define GI_AVAILABLE_IN_1_44                 _GI_EXTERN
 #endif
 
+#if GLIB_VERSION_MIN_REQUIRED >= GLIB_VERSION_2_46
+# define GI_DEPRECATED_IN_1_46                GLIB_DEPRECATED
+# define GI_DEPRECATED_IN_1_46_FOR(f)         GLIB_DEPRECATED_FOR(f)
+#else
+# define GI_DEPRECATED_IN_1_46                _GI_EXTERN
+# define GI_DEPRECATED_IN_1_46_FOR(f)         _GI_EXTERN
+#endif
+
+#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_46
+# define GI_AVAILABLE_IN_1_46                 GLIB_UNAVAILABLE(2, 46)
+#else
+# define GI_AVAILABLE_IN_1_46                 _GI_EXTERN
+#endif
+
+#if defined(GLIB_VERSION_2_60) && GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_60
+# define GI_AVAILABLE_IN_1_60                 GLIB_UNAVAILABLE(2, 60)
+#else
+# define GI_AVAILABLE_IN_1_60                 _GI_EXTERN
+#endif
+
+#if defined(GLIB_VERSION_2_66) && GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_66
+# define GI_AVAILABLE_IN_1_66                 GLIB_UNAVAILABLE(2, 66)
+#else
+# define GI_AVAILABLE_IN_1_66                 _GI_EXTERN
+#endif
+
 #endif /* __GIVERSIONMACROS_H__ */
